@@ -19,6 +19,7 @@ SERVICE_RENAMES = {
     'alexaforbusiness': 'alexa-for-business',
     'apigateway': 'api-gateway',
     'application-autoscaling': 'application-auto-scaling',
+    'appmesh': 'app-mesh',
     'autoscaling': 'auto-scaling',
     'autoscaling-plans': 'auto-scaling-plans',
     'ce': 'cost-explorer',
@@ -45,7 +46,10 @@ SERVICE_RENAMES = {
     'iot-jobs-data': 'iot-jobs-data-plane',
     'iot1click-devices': 'iot-1click-devices-service',
     'iot1click-projects': 'iot-1click-projects',
+    'iotevents-data': 'iot-events-data',
+    'iotevents': 'iot-events',
     'kinesisanalytics': 'kinesis-analytics',
+    'kinesisanalyticsv2': 'kinesis-analytics-v2',
     'kinesisvideo': 'kinesis-video',
     'lex-models': 'lex-model-building-service',
     'lex-runtime': 'lex-runtime-service',
@@ -78,6 +82,7 @@ ENDPOINT_PREFIX_OVERRIDE = {
     'application-autoscaling': 'autoscaling',
     # For neptune, we send requests to the RDS endpoint.
     'neptune': 'rds',
+    'docdb': 'rds',
 }
 NOT_SUPPORTED_IN_SDK = [
     'mobileanalytics',
